@@ -597,7 +597,7 @@ sub Run {
         if ( !IsHashRefWithData($ImportedConfig) ) {
             return $LayoutObject->ErrorScreen(
                 Message =>
-                    Translatable('The imported file has not valid YAML content! Please check OTRS log for details'),
+                    Translatable('The imported file has not valid YAML content! Please check Znuny log for details'),
             );
         }
 
@@ -910,23 +910,19 @@ sub _ShowEdit {
             $ExampleWebServicesData{$Key} = $Value;
         }
 
-        my %Frontend;
-
-        if ( %ExampleWebServicesData && $Kernel::OM->Get('Kernel::System::OTRSBusiness')->OTRSBusinessIsInstalled() ) {
-            $Frontend{ExampleWebServiceList} = $Kernel::OM->Get('Kernel::Output::HTML::Layout')->BuildSelection(
-                Name         => 'ExampleWebService',
-                Data         => \%ExampleWebServicesData,
-                PossibleNone => 1,
-                Translation  => 0,
-                Class        => 'Modernize Validate_Required',
-            );
-        }
+        my $ExampleWebServices = $Kernel::OM->Get('Kernel::Output::HTML::Layout')->BuildSelection(
+            Name         => 'ExampleWebService',
+            Data         => \%ExampleWebServicesData,
+            PossibleNone => 1,
+            Translation  => 0,
+            Class        => 'Modernize Validate_Required',
+        );
 
         # Enable Example web services.
         $LayoutObject->Block(
             Name => 'ExampleWebServices',
             Data => {
-                %Frontend,
+                ExampleWebServiceList => $ExampleWebServices,
             },
         );
     }
@@ -1067,7 +1063,7 @@ sub _ShowEdit {
     # Meta configuration for output blocks.
     my %CommTypeConfig = (
         Provider => {
-            Title                 => Translatable('OTRS as provider'),
+            Title                 => Translatable('Znuny as provider'),
             SelectedTransport     => $ProviderData->{Transport}->{Type},
             ActionType            => 'Operation',
             ActionsTitle          => Translatable('Operations'),
@@ -1077,7 +1073,7 @@ sub _ShowEdit {
             ErrorHandlingPriority => $ErrorHandlingPriorityProvider,
         },
         Requester => {
-            Title                 => Translatable('OTRS as requester'),
+            Title                 => Translatable('Znuny as requester'),
             SelectedTransport     => $RequesterData->{Transport}->{Type},
             ActionType            => 'Invoker',
             ActionsTitle          => Translatable('Invokers'),
